==> reagent-material-ui-js-5.0.0-0.jar: mui/mui.ext.js <==
var MuiMaterial = {
  Accordion: function () {},
  AccordionActions: function () {},
  AccordionDetails: function () {},
  AccordionSummary: function () {},
  Alert: function () {},
  AlertTitle: function () {},
  AppBar: function () {},
  Autocomplete: function () {},
  createFilterOptions: function () {},
  Avatar: function () {},
  AvatarGroup: function () {},
  Backdrop: function () {},
  Badge: function () {},
  BottomNavigation: function () {},
  BottomNavigationAction: function () {},
  Box: function () {},
  Breadcrumbs: function () {},
  Button: function () {},
  ButtonBase: function () {},
  ButtonGroup: function () {},
  Card: function () {},
  CardActionArea: function () {},
  CardActions: function () {},
  CardContent: function () {},
  CardHeader: function () {},
  CardMedia: function () {},
  Checkbox: function () {},
  Chip: function () {},
  CircularProgress: function () {},
  ClickAwayListener: function () {},
  Collapse: function () {},
  Container: function () {},
  CssBaseline: function () {},
  Dialog: function () {},
  DialogActions: function () {},
  DialogContent: function () {},
  DialogContentText: function () {},
  DialogTitle: function () {},
  Divider: function () {},
  Drawer: function () {},
  Fab: function () {},
  Fade: function () {},
  FilledInput: function () {},
  FormControl: function () {},
  useFormControl: function () {},
  FormControlLabel: function () {},
  FormGroup: function () {},
  FormHelperText: function () {},
  FormLabel: function () {},
  GlobalStyles: function () {},
  Grid: function () {},
  Grow: function () {},
  Hidden: function () {},
  Icon: function () {},
  IconButton: function () {},
  ImageList: function () {},
  ImageListItem: function () {},
  ImageListItemBar: function () {},
  Input: function () {},
  InputAdornment: function () {},
  InputBase: function () {},
  InputLabel: function () {},
  LinearProgress: function () {},
  Link: function () {},
  List: function () {},
  ListItem: function () {},
  ListItemAvatar: function () {},
  ListItemButton: function () {},
  ListItemIcon: function () {},
  ListItemSecondaryAction: function () {},
  ListItemText: function () {},
  ListSubheader: function () {},
  Menu: function () {},
  MenuItem: function () {},
  MenuList: function () {},
  MobileStepper: function () {},
  Modal: function () {},
  ModalManager: function () {},
  NativeSelect: function () {},
  NoSsr: function () {},
  OutlinedInput: function () {},
  Pagination: function () {},
  PaginationItem: function () {},
  Paper: function () {},
  Popover: function () {},
  Popper: function () {},
  Portal: function () {},
  Radio: function () {},
  RadioGroup: function () {},
  useRadioGroup: function () {},
  Rating: function () {},
  ScopedCssBaseline: function () {},
  Select: function () {},
  Skeleton: function () {},
  Slide: function () {},
  Slider: function () {},
  Snackbar: function () {},
  SnackbarContent: function () {},
  SpeedDial: function () {},
  SpeedDialAction: function () {},
  SpeedDialIcon: function () {},
  Stack: function () {},
  Step: function () {},
  StepButton: function () {},
  StepConnector: function () {},
  StepContent: function () {},
  StepIcon: function () {},
  StepLabel: function () {},
  Stepper: function () {},
  StyledEngineProvider: function () {},
  SvgIcon: function () {},
  SwipeableDrawer: function () {},
  Switch: function () {},
  Tab: function () {},
  TabScrollButton: function () {},
  Table: function () {},
  TableBody: function () {},
  TableCell: function () {},
  TableContainer: function () {},
  TableFooter: function () {},
  TableHead: function () {},
  TablePagination: function () {},
  TableRow: function () {},
  TableSortLabel: function () {},
  Tabs: function () {},
  TextField: function () {},
  TextareaAutosize: function () {},
  ToggleButton: function () {},
  ToggleButtonGroup: function () {},
  Toolbar: function () {},
  Tooltip: function () {},
  Typography: function () {},
  Unstable_TrapFocus: function () {},
  Zoom: function () {},
  useAutocomplete: function () {},
  useMediaQuery: function () {},
  usePagination: function () {},
  useScrollTrigger: function () {},
  useTouchRipple: function () {},
  styles: {
    StyledEngineProvider: function () {},
    ThemeProvider: function () {},
    adaptV4Theme: function () {},
    alpha: function () {},
    createMuiTheme: function () {},
    createStyles: function () {},
    createTheme: function () {},
    darken: function () {},
    decomposeColor: function () {},
    duration: function () {},
    easing: function () {},
    emphasize: function () {},
    experimentalStyled: function () {},
    getContrastRatio: function () {},
    getLuminance: function () {},
    hexToRgb: function () {},
    hslToRgb: function () {},
    lighten: function () {},
    recomposeColor: function () {},
    responsiveFontSizes: function () {},
    rgbToHex: function () {},
    styled: function () {},
    unstable_createMuiStrictModeTheme: function () {},
    unstable_getUnit: function () {},
    unstable_toUnitless: function () {},
    useTheme: function () {},
    useThemeProps: function () {}
  },
  utils: {
    capitalize: function () {},
    createChainedFunction: function () {},
    createSvgIcon: function () {},
    debounce: function () {},
    deprecatedPropType: function () {},
    isMuiElement: function () {},
    ownerDocument: function () {},
    ownerWindow: function () {},
    requirePropFactory: function () {},
    setRef: function () {},
    unstable_useEnhancedEffect: function () {},
    unstable_useId: function () {},
    unsupportedProp: function () {},
    useControlled: function () {},
    useEventCallback: function () {},
    useForkRef: function () {},
    useIsFocusVisible: function () {}
  }
};

var MuiLab = {
  CalendarPicker: function () {},
  CalendarPickerSkeleton: function () {},
  ClockPicker: function () {},
  DatePicker: function () {},
  DateRangePicker: function () {},
  DateRangePickerDay: function () {},
  DateTimePicker: function () {},
  DesktopDatePicker: function () {},
  DesktopDateRangePicker: function () {},
  DesktopDateTimePicker: function () {},
  DesktopTimePicker: function () {},
  LoadingButton: function () {},
  LocalizationProvider: function () {},
  Masonry: function () {},
  MasonryItem: function () {},
  MobileDatePicker: function () {},
  MobileDateRangePicker: function () {},
  MobileDateTimePicker: function () {},
  MobileTimePicker: function () {},
  MonthPicker: function () {},
  PickersDay: function () {},
  StaticDatePicker: function () {},
  StaticDateRangePicker: function () {},
  StaticDateTimePicker: function () {},
  StaticTimePicker: function () {},
  TabContext: function () {},
  useTabContext: function () {},
  TabList: function () {},
  TabPanel: function () {},
  TimePicker: function () {},
  Timeline: function () {},
  TimelineConnector: function () {},
  TimelineContent: function () {},
  TimelineDot: function () {},
  TimelineItem: function () {},
  TimelineOppositeContent: function () {},
  TimelineSeparator: function () {},
  TreeItem: function () {},
  useTreeItem: function () {},
  TreeView: function () {},
  YearPicker: function () {}
};

var MuiCore = {
  BackdropUnstyled: function () {},
  BadgeUnstyled: function () {},
  ModalManager: function () {},
  ModalUnstyled: function () {},
  NoSsr: function () {},
  Portal: function () {},
  SliderUnstyled: function () {},
  SliderValueLabelUnstyled: function () {},
  SwitchUnstyled: function () {},
  Unstable_TrapFocus: function () {},
  backdropUnstyledClasses: function () {},
  badgeUnstyledClasses: function () {},
  generateUtilityClass: function () {},
  generateUtilityClasses: function () {},
  getBackdropUtilityClass: function () {},
  getBadgeUtilityClass: function () {},
  getModalUtilityClass: function () {},
  getSliderUtilityClass: function () {},
  getSwitchUnstyledUtilityClass: function () {},
  isHostComponent: function () {},
  modalUnstyledClasses: function () {},
  sliderUnstyledClasses: function () {},
  switchUnstyledClasses: function () {},
  unstable_composeClasses: function () {},
  useSwitch: function () {}
};

var MuiStyles = {
  ServerStyleSheets: function () {},
  StylesContext: function () {},
  StylesProvider: function () {},
  ThemeProvider: function () {},
  createGenerateClassName: function () {},
  createStyles: function () {},
  getThemeProps: function () {},
  jssPreset: function () {},
  makeStyles: function () {},
  mergeClasses: function () {},
  propsToClassKey: function () {},
  sheetsManager: function () {},
  styled: function () {},
  useTheme: function () {},
  useThemeVariants: function () {},
  withStyles: function () {},
  withTheme: function () {},
  withThemeCreator: function () {}
};

var MuiUtils = {
  HTMLElementType: function () {},
  chainPropTypes: function () {},
  deepmerge: function () {},
  elementAcceptingRef: function () {},
  elementTypeAcceptingRef: function () {},
  exactProp: function () {},
  formatMuiErrorMessage: function () {},
  getDisplayName: function () {},
  integerPropType: function () {},
  ponyfillGlobal: function () {},
  refType: function () {},
  unstable_capitalize: function () {},
  unstable_createChainedFunction: function () {},
  unstable_debounce: function () {},
  unstable_deprecatedPropType: function () {},
  unstable_detectScrollType: function () {},
  unstable_getNormalizedScrollLeft: function () {},
  unstable_getScrollbarSize: function () {},
  unstable_isMuiElement: function () {},
  unstable_ownerDocument: function () {},
  unstable_ownerWindow: function () {},
  unstable_requirePropFactory: function () {},
  unstable_setRef: function () {},
  unstable_unsupportedProp: function () {},
  unstable_useControlled: function () {},
  unstable_useEnhancedEffect: function () {},
  unstable_useEventCallback: function () {},
  unstable_useForkRef: function () {},
  unstable_useId: function () {},
  unstable_useIsFocusVisible: function () {},
  usePreviousProps: function () {},
  visuallyHidden: function () {}
};

==> reagent-material-ui-js-5.2.4-0.jar: mui/mui.ext.js <==
var MuiMaterial = {
  Accordion: function () {},
  AccordionActions: function () {},
  AccordionDetails: function () {},
  AccordionSummary: function () {},
  Alert: function () {},
  AlertTitle: function () {},
  AppBar: function () {},
  Autocomplete: function () {},
  createFilterOptions: function () {},
  Avatar: function () {},
  AvatarGroup: function () {},
  Backdrop: function () {},
  Badge: function () {},
  BottomNavigation: function () {},
  BottomNavigationAction: function () {},
  Box: function () {},
  Breadcrumbs: function () {},
  Button: function () {},
  ButtonBase: function () {},
  ButtonGroup: function () {},
  Card: function () {},
  CardActionArea: function () {},
  CardActions: function () {},
  CardContent: function () {},
  CardHeader: function () {},
  CardMedia: function () {},
  Checkbox: function () {},
  Chip: function () {},
  CircularProgress: function () {},
  ClickAwayListener: function () {},
  Collapse: function () {},
  Container: function () {},
  CssBaseline: function () {},
  Dialog: function () {},
  DialogActions: function () {},
  DialogContent: function () {},
  DialogContentText: function () {},
  DialogTitle: function () {},
  Divider: function () {},
  Drawer: function () {},
  Fab: function () {},
  Fade: function () {},
  FilledInput: function () {},
  FormControl: function () {},
  useFormControl: function () {},
  FormControlLabel: function () {},
  FormGroup: function () {},
  FormHelperText: function () {},
  FormLabel: function () {},
  GlobalStyles: function () {},
  Grid: function () {},
  Grow: function () {},
  Hidden: function () {},
  Icon: function () {},
  IconButton: function () {},
  ImageList: function () {},
  ImageListItem: function () {},
  ImageListItemBar: function () {},
  Input: function () {},
  InputAdornment: function () {},
  InputBase: function () {},
  InputLabel: function () {},
  LinearProgress: function () {},
  Link: function () {},
  List: function () {},
  ListItem: function () {},
  ListItemAvatar: function () {},
  ListItemButton: function () {},
  ListItemIcon: function () {},
  ListItemSecondaryAction: function () {},
  ListItemText: function () {},
  ListSubheader: function () {},
  Menu: function () {},
  MenuItem: function () {},
  MenuList: function () {},
  MobileStepper: function () {},
  Modal: function () {},
  ModalManager: function () {},
  NativeSelect: function () {},
  NoSsr: function () {},
  OutlinedInput: function () {},
  Pagination: function () {},
  PaginationItem: function () {},
  Paper: function () {},
  Popover: function () {},
  Popper: function () {},
  Portal: function () {},
  Radio: function () {},
  RadioGroup: function () {},
  useRadioGroup: function () {},
  Rating: function () {},
  ScopedCssBaseline: function () {},
  Select: function () {},
  Skeleton: function () {},
  Slide: function () {},
  Slider: function () {},
  Snackbar: function () {},
  SnackbarContent: function () {},
  SpeedDial: function () {},
  SpeedDialAction: function () {},
  SpeedDialIcon: function () {},
  Stack: function () {},
  Step: function () {},
  StepButton: function () {},
  StepConnector: function () {},
  StepContent: function () {},
  StepIcon: function () {},
  StepLabel: function () {},
  Stepper: function () {},
  StyledEngineProvider: function () {},
  SvgIcon: function () {},
  SwipeableDrawer: function () {},
  Switch: function () {},
  Tab: function () {},
  TabScrollButton: function () {},
  Table: function () {},
  TableBody: function () {},
  TableCell: function () {},
  TableContainer: function () {},
  TableFooter: function () {},
  TableHead: function () {},
  TablePagination: function () {},
  TableRow: function () {},
  TableSortLabel: function () {},
  Tabs: function () {},
  TextField: function () {},
  TextareaAutosize: function () {},
  ToggleButton: function () {},
  ToggleButtonGroup: function () {},
  Toolbar: function () {},
  Tooltip: function () {},
  Typography: function () {},
  Unstable_TrapFocus: function () {},
  Zoom: function () {},
  useAutocomplete: function () {},
  useMediaQuery: function () {},
  usePagination: function () {},
  useScrollTrigger: function () {},
  useTouchRipple: function () {},
  styles: {
    StyledEngineProvider: function () {},
    ThemeProvider: function () {},
    adaptV4Theme: function () {},
    alpha: function () {},
    createMuiTheme: function () {},
    createStyles: function () {},
    createTheme: function () {},
    css: function () {},
    darken: function () {},
    decomposeColor: function () {},
    duration: function () {},
    easing: function () {},
    emphasize: function () {},
    experimentalStyled: function () {},
    experimental_sx: function () {},
    getContrastRatio: function () {},
    getLuminance: function () {},
    hexToRgb: function () {},
    hslToRgb: function () {},
    keyframes: function () {},
    lighten: function () {},
    makeStyles: function () {},
    recomposeColor: function () {},
    responsiveFontSizes: function () {},
    rgbToHex: function () {},
    styled: function () {},
    unstable_createMuiStrictModeTheme: function () {},
    unstable_getUnit: function () {},
    unstable_toUnitless: function () {},
    useTheme: function () {},
    useThemeProps: function () {},
    withStyles: function () {},
    withTheme: function () {}
  },
  utils: {
    capitalize: function () {},
    createChainedFunction: function () {},
    createSvgIcon: function () {},
    debounce: function () {},
    deprecatedPropType: function () {},
    isMuiElement: function () {},
    ownerDocument: function () {},
    ownerWindow: function () {},
    requirePropFactory: function () {},
    setRef: function () {},
    unstable_ClassNameGenerator: function () {},
    unstable_useEnhancedEffect: function () {},
    unstable_useId: function () {},
    unsupportedProp: function () {},
    useControlled: function () {},
    useEventCallback: function () {},
    useForkRef: function () {},
    useIsFocusVisible: function () {}
  }
};

var MuiLab = {
  CalendarPicker: function () {},
  CalendarPickerSkeleton: function () {},
  ClockPicker: function () {},
  DatePicker: function () {},
  DateRangePicker: function () {},
  DateRangePickerDay: function () {},
  DateTimePicker: function () {},
  DesktopDatePicker: function () {},
  DesktopDateRangePicker: function () {},
  DesktopDateTimePicker: function () {},
  DesktopTimePicker: function () {},
  LoadingButton: function () {},
  LocalizationProvider: function () {},
  Masonry: function () {},
  MasonryItem: function () {},
  MobileDatePicker: function () {},
  MobileDateRangePicker: function () {},
  MobileDateTimePicker: function () {},
  MobileTimePicker: function () {},
  MonthPicker: function () {},
  PickersDay: function () {},
  StaticDatePicker: function () {},
  StaticDateRangePicker: function () {},
  StaticDateTimePicker: function () {},
  StaticTimePicker: function () {},
  TabContext: function () {},
  useTabContext: function () {},
  TabList: function () {},
  TabPanel: function () {},
  TimePicker: function () {},
  Timeline: function () {},
  TimelineConnector: function () {},
  TimelineContent: function () {},
  TimelineDot: function () {},
  TimelineItem: function () {},
  TimelineOppositeContent: function () {},
  TimelineSeparator: function () {},
  TreeItem: function () {},
  useTreeItem: function () {},
  TreeView: function () {},
  YearPicker: function () {}
};

var MuiBase = {
  BackdropUnstyled: function () {},
  BadgeUnstyled: function () {},
  ButtonUnstyled: function () {},
  ClickAwayListener: function () {},
  FormControlUnstyled: function () {},
  FormControlUnstyledContext: function () {},
  InputUnstyled: function () {},
  ModalManager: function () {},
  ModalUnstyled: function () {},
  NoSsr: function () {},
  PopperUnstyled: function () {},
  Portal: function () {},
  SliderUnstyled: function () {},
  SliderValueLabelUnstyled: function () {},
  SwitchUnstyled: function () {},
  TabPanelUnstyled: function () {},
  TabUnstyled: function () {},
  TabsContext: function () {},
  TabsListUnstyled: function () {},
  TabsUnstyled: function () {},
  TextareaAutosize: function () {},
  Unstable_TrapFocus: function () {},
  appendOwnerState: function () {},
  backdropUnstyledClasses: function () {},
  badgeUnstyledClasses: function () {},
  buttonUnstyledClasses: function () {},
  createFilterOptions: function () {},
  extractEventHandlers: function () {},
  formControlUnstyledClasses: function () {},
  generateUtilityClass: function () {},
  generateUtilityClasses: function () {},
  getBackdropUtilityClass: function () {},
  getBadgeUtilityClass: function () {},
  getButtonUnstyledUtilityClass: function () {},
  getFormControlUnstyledUtilityClasses: function () {},
  getInputUnstyledUtilityClass: function () {},
  getModalUtilityClass: function () {},
  getPanelId: function () {},
  getSliderUtilityClass: function () {},
  getSwitchUnstyledUtilityClass: function () {},
  getTabId: function () {},
  getTabPanelUnstyledUtilityClass: function () {},
  getTabUnstyledUtilityClass: function () {},
  getTabsListUnstyledUtilityClass: function () {},
  getTabsUnstyledUtilityClass: function () {},
  inputUnstyledClasses: function () {},
  isHostComponent: function () {},
  modalUnstyledClasses: function () {},
  sliderUnstyledClasses: function () {},
  switchUnstyledClasses: function () {},
  tabPanelUnstyledClasses: function () {},
  tabUnstyledClasses: function () {},
  tabsListUnstyledClasses: function () {},
  tabsUnstyledClasses: function () {},
  unstable_ClassNameGenerator: function () {},
  unstable_composeClasses: function () {},
  useAutocomplete: function () {},
  useButton: function () {},
  useFormControlUnstyled: function () {},
  useInput: function () {},
  useSwitch: function () {},
  useTab: function () {},
  useTabContext: function () {},
  useTabPanel: function () {},
  useTabs: function () {},
  useTabsList: function () {}
};

var MuiStyles = {
  ServerStyleSheets: function () {},
  StylesContext: function () {},
  StylesProvider: function () {},
  ThemeProvider: function () {},
  createGenerateClassName: function () {},
  createStyles: function () {},
  getThemeProps: function () {},
  jssPreset: function () {},
  makeStyles: function () {},
  mergeClasses: function () {},
  propsToClassKey: function () {},
  sheetsManager: function () {},
  styled: function () {},
  useTheme: function () {},
  useThemeVariants: function () {},
  withStyles: function () {},
  withTheme: function () {},
  withThemeCreator: function () {}
};

var MuiUtils = {
  HTMLElementType: function () {},
  chainPropTypes: function () {},
  deepmerge: function () {},
  elementAcceptingRef: function () {},
  elementTypeAcceptingRef: function () {},
  exactProp: function () {},
  formatMuiErrorMessage: function () {},
  getDisplayName: function () {},
  integerPropType: function () {},
  internal_resolveProps: function () {},
  isPlainObject: function () {},
  ponyfillGlobal: function () {},
  refType: function () {},
  unstable_capitalize: function () {},
  unstable_createChainedFunction: function () {},
  unstable_debounce: function () {},
  unstable_deprecatedPropType: function () {},
  unstable_detectScrollType: function () {},
  unstable_getNormalizedScrollLeft: function () {},
  unstable_getScrollbarSize: function () {},
  unstable_isMuiElement: function () {},
  unstable_ownerDocument: function () {},
  unstable_ownerWindow: function () {},
  unstable_requirePropFactory: function () {},
  unstable_setRef: function () {},
  unstable_unsupportedProp: function () {},
  unstable_useControlled: function () {},
  unstable_useEnhancedEffect: function () {},
  unstable_useEventCallback: function () {},
  unstable_useForkRef: function () {},
  unstable_useId: function () {},
  unstable_useIsFocusVisible: function () {},
  usePreviousProps: function () {},
  visuallyHidden: function () {}
};
